@@ -291,7 +291,7 @@ class VMOps(object):
             raise exception.InstanceExists(name=instance_name)
 
         # Make sure we're starting with a clean slate.
-        self._delete_disk_files(instance_name)
+        self._delete_disk_files(instance)
 
         vm_gen = self.get_image_vm_generation(instance.uuid, image_meta)
 
@@ -333,9 +333,11 @@ class VMOps(object):
     @contextlib.contextmanager
     def wait_vif_plug_events(self, instance, network_info):
         timeout = CONF.vif_plugging_timeout
-        events = self._get_neutron_events(network_info)
 
         try:
+            # NOTE(claudiub): async calls to bind the neutron ports will be
+            # done when network_info is being accessed.
+            events = self._get_neutron_events(network_info)
             with self._virtapi.wait_for_instance_event(
                     instance, events, deadline=timeout,
                     error_callback=self._neutron_failed_callback):
@@ -346,6 +348,18 @@ class VMOps(object):
                         'instance.', instance=instance)
             if CONF.vif_plugging_is_fatal:
                 raise exception.VirtualInterfaceCreateException()
+        except exception.PortBindingFailed:
+            LOG.warning(
+                "Neutron failed to bind a port to this host. Make sure that "
+                "an L2 agent is registered on this node and alive (Neutron "
+                "Open vSwitch agent or Hyper-V agent), or that Neutron is "
+                "configured with a mechanism driver that is able to bind "
+                "ports without requiring an L2 agent on this host (e.g. OVN "
+                "mechanism driver). If you're using Neutron Hyper-V agent, "
+                "make sure that networking-hyperv is installed on the "
+                "Neutron controller and that the neutron-server service was "
+                "configured to use the 'hyperv' mechanism_driver.")
+            raise
 
     def _neutron_failed_callback(self, event_name, instance):
         LOG.error('Neutron Reported failure on event %s',
@@ -790,23 +804,32 @@ class VMOps(object):
                 self._pathutils.remove(configdrive_path)
 
     @serialconsoleops.instance_synchronized
-    def _delete_disk_files(self, instance_name, instance_path=None):
+    def _delete_disk_files(self, instance, instance_path=None,
+                           cleanup_migration_files=True):
         # We want to avoid the situation in which serial console workers
         # are started while we perform this operation, preventing us from
         # deleting the instance log files (bug #1556189). This can happen
         # due to delayed instance lifecycle events.
         #
         # The unsynchronized method is being used to avoid a deadlock.
-        self._serial_console_ops.stop_console_handler_unsync(instance_name)
+        self._serial_console_ops.stop_console_handler_unsync(instance.name)
 
         # This may be a 'non-default' location.
         if not instance_path:
-            instance_path = self._pathutils.get_instance_dir(instance_name)
+            instance_path = self._pathutils.get_instance_dir(instance.name)
 
         self._pathutils.check_remove_dir(instance_path)
 
+        if cleanup_migration_files:
+            self._pathutils.get_instance_migr_revert_dir(
+                instance_path, remove_dir=True)
+
+            backup_location = instance.system_metadata.get('backup_location')
+            if backup_location:
+                self._pathutils.check_remove_dir(backup_location)
+
     def destroy(self, instance, network_info, block_device_info,
-                destroy_disks=True):
+                destroy_disks=True, cleanup_migration_files=True):
         instance_name = instance.name
         LOG.info("Got request to destroy instance", instance=instance)
 
@@ -834,7 +857,8 @@ class VMOps(object):
             self._volumeops.disconnect_volumes(block_device_info)
 
             if destroy_disks:
-                self._delete_disk_files(instance_name, instance_path)
+                self._delete_disk_files(instance, instance_path,
+                                        cleanup_migration_files)
         except Exception:
             with excutils.save_and_reraise_exception():
                 LOG.exception('Failed to destroy instance: %s', instance_name)
